Puppet::Type.type(:network_route).provide(:network_scripts) do
  desc "Provider for configuration of network_route"

  defaultfor :operatingsystem => [:redhat, :fedora, :centos]

  @@exclusive_routes= nil
  @@configured_routes = []
  @@config_dir_routes = "/etc/sysconfig/network-scripts/"
  @@instance_routes_count = 0
  @@total_resource_routes_count = 0

  # checks for network-script existence and correctness
  def exists?
    @@instance_routes_count += 1
    @config_file = "#{@@config_dir}route-#{@resource[:name]}"

    # do not check file contents if the purpose is to ensure the file isn't there
    return File.exists?(@config_file) if @resource[:ensure] == :absent

    # load puppet configuration (`should`)
    @memory_values = []

    for route in @resource[:routes]
      @memory_values.push(route.strip)
    end

    # handle the special hack with :exclusive
    @@exclusive_routes = @resource.to_hash[:exclusive] if @@exclusive_routes.nil?

    # load on-disk configuration (`is`)
    @disk_values = load_disk_config()

    # if this is the last file to be checked, trigger exclusivity enforcement
    enforce_exclusivity if (@@instance_routes_count == @@total_resource_routes_count)

    return @disk_values == @memory_values
  end

  def create
    File.open(@config_file.to_s, 'w') do |f|
      f.write("# Generated by puppet-network on #{Time.now.strftime("%F %T")}\n")
      for line in @memory_values
        f.write("#{line.to_s.strip}\n")
      end
    end
  end

  def destroy
    if File.exists?(@config_file)
      Puppet.notice "Destroying #{@config_file}"
      File.unlink(@config_file)
    end
  end

  # Reads the content in the config file and returns a hash of keys & values
  def load_disk_config
    return nil unless File.exists?(@config_file)

    config_array = []

    File.readlines(@config_file).each do |line|
      next if line =~ /^#.*$/
      config_array.push(line.to_s.strip)
    end

    Puppet.debug "Loaded file: #{@config_file}"
    return config_array
  end

  #
  # `exclusive` related code
  #

  def initialize(args)
    super(args)
    @@configured_routes << "route-#{@resource[:device]}"
    @@total_resource_routes_count += 1
  end

  def clear
    @@configured_routes = []
    @@instance_routes_count = 0
    @@total_resource_routes_count = 0
    @@exclusive_routes = nil
  end

  # gets called once every network_config resource has been declared.
  def enforce_exclusivity
    unless @@exclusive_routes == :false
      existing = Dir["#{@@config_dir}route-*"].map { |f| File.basename(f) }
      (existing - @@configured_routes).each do |parasite_file|
        Puppet.notice "puppet-network exclusive: removing #{parasite_file}"
        File.delete("#{@@config_dir}#{parasite_file}")
      end
    end
    clear()
  end
end
